@@ -135,11 +135,16 @@ class AppSettings(object):
                                                 'description',
                                                 'picture',
                                                 'birthdate',
+                                                'country_of_birth',
                                                 'latitude', 'longitude',
                                                 'country',
                                                 'address',
                                                 'language',
-                                                'alias'), tuple)
+                                                'alias',
+                                                'company_name',
+                                                'expiration_date',
+                                                'external_id',
+                                                'gender'), tuple)
 
     @property
     def REQUIRED_PROFILE_FIELDS(self):
