@@ -122,6 +122,8 @@ def api_gateway_signal_handler_when_profile_is_added_to_or_removed_from_group(ac
 
                     if not is_loaddata:  # or is_apigateway_update):
                         profile.update_rev(True)
+                elif status_code == 409:
+                    logger.debug('acl group "{} already created'.format(group.name))
                 else:
                     logger.exception('error ({}) creating api gateway acl group'.format(status_code))
 
@@ -138,5 +140,7 @@ def api_gateway_signal_handler_when_profile_is_added_to_or_removed_from_group(ac
 
                     if not is_loaddata:
                         profile.update_rev(True)
+                elif status_code == 404:
+                    logger.debug('acl group "{} already deleted'.format(group.name))
                 else:
                     logger.exception('error ({}) deleting api gateway acl group'.format(status_code))
