@@ -30,6 +30,7 @@ class SsoIdPKManager(models.Manager):
 class AbstractProfileModel(CreatedAtModel, UpdatableModel, DeactivableModel, PublicableModel):
     """
     Profile abstract model
+
     """
 
     class Meta:
@@ -40,12 +41,14 @@ class AbstractProfileModel(CreatedAtModel, UpdatableModel, DeactivableModel, Pub
     def natural_key(self):
         return (self.sso_id, )
 
-    sso_id = models.CharField(_('sso id'), max_length=36, unique=True, db_index=True, default=_get_new_uuid)  # unique on not null , editable=False
+    sso_id = models.CharField(_('sso id'), max_length=36, unique=True, default=_get_new_uuid, db_index=True)  # unique on not null , editable=False
     sso_rev = models.PositiveIntegerField(_('sso revision'), default=1)
 
     django_user_username = models.CharField(_('user username'), max_length=150, null=True, blank=True, editable=False)
     django_user_email = models.EmailField(_('email address'), null=True, blank=True, editable=False)
 
+    external_id = models.CharField(_('external id'), max_length=36, null=True, blank=True, db_index=True)
+
     ssn = models.CharField(_('social security number'), max_length=255, null=True, blank=True)
     phone = models.CharField(_('phone'), max_length=255, null=True, blank=True)
 
@@ -57,7 +60,9 @@ class AbstractProfileModel(CreatedAtModel, UpdatableModel, DeactivableModel, Pub
 
     description = models.TextField(_('description'), null=True, blank=True)
     picture = models.TextField(_('picture'), null=True, blank=True)
+
     birthdate = models.DateField(_('birthdate'), null=True, blank=True)
+    country_of_birth = CountryField(_('country of birth'), max_length=46, null=True, blank=True)
 
     latitude = models.FloatField(_('latitude'), null=True, blank=True)
     longitude = models.FloatField(_('longitude'), null=True, blank=True)
@@ -69,10 +74,16 @@ class AbstractProfileModel(CreatedAtModel, UpdatableModel, DeactivableModel, Pub
     address = models.TextField(_('address'), null=True, blank=True)
     language = models.CharField(_('language'), max_length=3, null=True, blank=True)
 
-    unsubscribed_at = models.DateTimeField(_('unsubscription date'), null=True, blank=True)
+    gender = models.CharField(_('gender'), max_length=15, null=True, blank=True)
+
+    company_name = CountryField(_('company name'), max_length=255, null=True, blank=True)
+
+    expiration_date = models.DateTimeField(_('expiration date'), null=True, blank=True)
 
     completed_at = models.DateTimeField(_('profile completion date'), null=True, blank=True)
 
+    unsubscribed_at = models.DateTimeField(_('unsubscription date'), null=True, blank=True)
+
     meta = models.TextField(_('meta'), null=True, blank=True)
 
     @property
