@@ -85,6 +85,7 @@ class TestApp(UserTestCase):
             self.assertEqual(response.data.get('sso_id'), remote_profile_uuid, 'sso_id differs from remote and local')
 
             created_profile = Profile.objects.filter(sso_id=remote_profile_uuid).first()
+            # self.assertEqual(response.data.get('sso_id'), remote_profile_uuid, 'sso_id differs from remote and local')
 
             self.assertEqual(created_profile.groups.count(), 1, 'no profile groups created')
             self.assertEqual(created_profile.groups.filter(name=remote_user_group_name).count(), 1,
@@ -118,7 +119,7 @@ class TestApp(UserTestCase):
             created_profile = Profile.objects.get(sso_id=remote_profile_uuid)
 
             self.assertEqual(Profile.objects.filter(sso_id=remote_profile_uuid).count(), 1, 'no new user created')
-            self.assertEqual(created_profile.groups.count(), 2, 'group not created')  # groups plus incomplete
+            self.assertEqual(created_profile.groups.count(), 1, 'group not created')
             self.assertEqual(created_profile.groups.filter(name=remote_user_group_name).count(), 1,
                              'group not equals header defined')
 
@@ -141,7 +142,7 @@ class TestApp(UserTestCase):
                                                               service_subscribed=False)
 
             mocked_url = app_settings.REMOTE_USER_URL.format(sso_id=remote_profile_uuid)
-            profile_url = reverse('django_sso_app_profile:rest-detail', args=(remote_profile_uuid,))
+            #profile_url = reverse('django_sso_app_profile:rest-detail', args=(remote_profile_uuid,))
 
             self._set_mocked_response(mocked_url, remote_user_object)
 
@@ -149,7 +150,7 @@ class TestApp(UserTestCase):
             client.cookies = self._get_valid_jwt_cookie(remote_profile_uuid)
 
             response = client.get(
-                profile_url,
+                '/',
                 content_type='application/json'
             )
 
@@ -181,7 +182,7 @@ class TestApp(UserTestCase):
                                                               service_subscribed=False)
 
             mocked_url = app_settings.REMOTE_USER_URL.format(sso_id=remote_profile_uuid)
-            profile_url = reverse('django_sso_app_profile:rest-detail', args=(remote_profile_uuid,))
+            #profile_url = reverse('django_sso_app_profile:rest-detail', args=(remote_profile_uuid,))
 
             self._set_mocked_response(mocked_url, remote_user_object)
 
@@ -189,7 +190,7 @@ class TestApp(UserTestCase):
             client.cookies = self._get_valid_jwt_cookie(remote_profile_uuid)
 
             response = client.get(
-                profile_url,
+                '/',
                 content_type='application/json'
             )
 
@@ -222,14 +223,15 @@ class TestApp(UserTestCase):
                                                               incomplete=True)
 
             mocked_url = app_settings.REMOTE_USER_URL.format(sso_id=remote_profile_uuid)
-            profile_url = reverse('django_sso_app_profile:rest-detail', args=(remote_profile_uuid,))
+            #profile_url = reverse('django_sso_app_profile:rest-detail', args=(remote_profile_uuid,))
+
             self._set_mocked_response(mocked_url, remote_user_object)
 
             client = self._get_client()
             client.cookies = self._get_valid_jwt_cookie(remote_profile_uuid)
 
             response = client.get(
-                profile_url,
+                '/',
                 content_type='application/json'
             )
 
@@ -262,7 +264,7 @@ class TestApp(UserTestCase):
                                                               incomplete=True)
 
             mocked_url = app_settings.REMOTE_USER_URL.format(sso_id=remote_profile_uuid)
-            profile_url = reverse('django_sso_app_profile:rest-detail', args=(remote_profile_uuid,))
+            # profile_url = reverse('django_sso_app_profile:rest-detail', args=(remote_profile_uuid,))
 
             self._set_mocked_response(mocked_url, remote_user_object)
 
@@ -270,7 +272,7 @@ class TestApp(UserTestCase):
             client.cookies = self._get_valid_jwt_cookie(remote_profile_uuid)
 
             response = client.get(
-                profile_url,
+                '/',
                 content_type='application/json',
                 HTTP_X_CONSUMER_CUSTOM_ID=remote_profile_uuid,
                 HTTP_X_CONSUMER_GROUPS=remote_user_group_name
