@@ -9,7 +9,7 @@ from django.contrib.auth import get_user_model
 
 from ... import app_settings
 from ..emails.models import EmailAddress
-from ..profiles.utils import update_profile, create_update_profile_subscriptions
+from ..profiles.utils import update_profile
 from ..api_gateway.functions import get_apigateway_profile_groups_from_header
 
 logger = logging.getLogger('django_sso_app.core.apps.users')
@@ -25,10 +25,12 @@ def fetch_remote_user(sso_id, encoded_jwt=None):
     logger.info("Getting SSO profile for ID {} ...".format(sso_id))
 
     if encoded_jwt is None:
+        logger.debug('Using Token')
         headers = {
             "Authorization": "Token {}".format(app_settings.BACKEND_STAFF_TOKEN)
         }
     else:
+        logger.debug('Using JWT')
         headers = {
             "Authorization": "Bearer {}".format(encoded_jwt)
         }
@@ -254,11 +256,6 @@ def create_local_user_from_remote_backend(remote_user_object, can_subscribe=Fals
 
     setattr(new_user, '__dssoa__remote_user', remote_user_object)  # noqa (subscription required)
 
-    # create subscriptions
-    remote_object_profile = remote_user_object['profile']
-    _active_subscriptions, _disabled_subscriptions = create_update_profile_subscriptions(new_user.sso_app_profile,
-                                                                                         remote_object_profile)
-
     return new_user
 
 
@@ -276,7 +273,5 @@ def update_local_user_from_remote_backend(remote_user_object, profile, commit=Tr
     remote_object_profile = remote_user_object['profile']
     # update profile
     setattr(user, 'sso_app_profile', update_profile(profile, remote_object_profile, commit))
-    # update subscriptions
-    _active_subscriptions, _disabled_subscriptions = create_update_profile_subscriptions(profile, remote_object_profile)
 
     return user
