@@ -1,6 +1,7 @@
 import uuid as uuid_lib
 
 import responses
+from dateutil import tz
 
 from django.contrib.auth import get_user_model
 from django.contrib.auth.hashers import make_password
@@ -44,6 +45,10 @@ class UserTestCase(TestCase):
     def _get_random_email(self):
         return fake.ascii_safe_email()
 
+    def _get_random_datetime(self, start_datetime=None):
+        d = fake.date_time_between(start_date=start_datetime, end_date='+100y', tzinfo=tz.gettz('UTC'))
+        return d.isoformat()
+
     def _get_random_birthdate(self, start_date='-99y', end_date='-18y'):
         d = fake.date_time_between(start_date=start_date, end_date=end_date)
         return d.strftime('%Y-%m-%d')
@@ -82,16 +87,20 @@ class UserTestCase(TestCase):
         for f in app_settings.PROFILE_FIELDS:
             if f == 'birthdate':
                 obj[f] = self._get_random_birthdate()
+            elif f == 'expiration_date':
+                obj[f] = self._get_random_datetime(start_datetime=datetime.now())
             elif f == 'picture':
                 pass
             elif f == 'language':
                 obj[f] = language or self._get_random_languagecode()
-            elif f == 'country':
+            elif f in ['country', 'country_of_birth']:
                 obj[f] = country or self._get_random_country()
             elif f == 'latitude':
                 obj[f] = self._get_random_latitude()
             elif f == 'longitude':
                 obj[f] = self._get_random_longitude()
+            elif f == 'gender':
+                obj[f] = self._get_random_string(15)
             else:
                 obj[f] = self._get_random_string()
 
